#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 postgrest
version:              10.1.0
visibility:           public
id:                   postgrest-10.1.0-nHbDctnW3E5rGoaT5yuHD
key:                  postgrest-10.1.0-nHbDctnW3E5rGoaT5yuHD
license:              MIT
maintainer:           Steve Chavez <stevechavezast@gmail.com>
author:               Joe Nelson, Adam Baker, Steve Chavez
homepage:             https://postgrest.org
synopsis:             REST API for any Postgres database
description:
    Reads the schema of a PostgreSQL database and creates RESTful routes
    for tables, views, and functions, supporting all HTTP methods that security
    permits.

category:             Executable, PostgreSQL, Network APIs
abi:                  8e86ec65e24d3255733dc2da2739c3b4
exposed:              True
exposed-modules:
    PostgREST.ApiRequest PostgREST.ApiRequest.Preferences
    PostgREST.ApiRequest.QueryParams PostgREST.ApiRequest.Types
    PostgREST.App PostgREST.AppState PostgREST.Auth PostgREST.CLI
    PostgREST.Config PostgREST.Config.Database PostgREST.Config.JSPath
    PostgREST.Config.PgVersion PostgREST.Config.Proxy PostgREST.Cors
    PostgREST.Error PostgREST.Logger PostgREST.MediaType PostgREST.Plan
    PostgREST.Plan.CallPlan PostgREST.Plan.MutatePlan
    PostgREST.Plan.ReadPlan PostgREST.Query
    PostgREST.Query.QueryBuilder PostgREST.Query.SqlFragment
    PostgREST.Query.Statements PostgREST.RangeQuery PostgREST.Response
    PostgREST.Response.GucHeader PostgREST.Response.OpenAPI
    PostgREST.SchemaCache PostgREST.SchemaCache.Identifiers
    PostgREST.SchemaCache.Proc PostgREST.SchemaCache.Relationship
    PostgREST.SchemaCache.Table PostgREST.Unix PostgREST.Version
    PostgREST.Workers

hidden-modules:       Paths_postgrest
import-dirs:          /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/postgrest
hs-libraries:         HSpostgrest-10.1.0-nHbDctnW3E5rGoaT5yuHD
depends:
    HTTP-4000.5.0-2qzBfc5k9lK856jPzUViSF
    Ranged-sets-0.5.0-4yjVcGVIwvCB2AHFjddmKH
    aeson-2.2.2.0-Fs8lpfl0CTvIUZfvQfMaj3
    auto-update-0.1.6-DCT1CbkQUoLEWifEHxjBqG base-4.18.2.1
    base64-bytestring-1.2.1.0-3XLIeJQ91UN2UuX85CYnso
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-75BwTjwSfoc3sgy0QhC9q4
    cassava-0.5.4.1-CH4uCK7mHTAD3atJzcUjP2
    configurator-pg-0.2.11-KlVUKfLpbam8Amqtu3ZtCy containers-0.6.7
    contravariant-extras-0.3.5.4-Jp1EzHgD0E5KQ707vKnuxI
    cookie-0.5.0-Dqi2dsQ09KG8Z0mbWITxu5 directory-1.3.8.5
    either-5.0.3-HP9BS99MwrmJilazxTVXaq
    gitrev-1.3.1-HjgHeGOzFY1JvYhlt8eDSs
    hasql-1.6.1.1-BSZhw7HrHRQ6ovDsSSucYr
    hasql-dynamic-statements-0.3.1.2-6ySahCJY7miH4hhWthlEzb
    hasql-notifications-0.2.0.6-1RZdArB3C0NPeuoNZrzPV
    hasql-pool-0.8.0.2-L4htp8yskHYCFBgtrISgbx
    hasql-transaction-1.0.1.2-NRPAbGktb77FQrHzloQZQ
    heredoc-0.2.0.0-6fzsisYvDUd6tBbd4jIzIt
    http-types-0.12.4-LNdcYYtCiEAAA2abLyIqKh
    insert-ordered-containers-0.2.5.3-7O8n00xQuIuGr0MfkGaKJy
    interpolatedstring-perl6-1.0.2-CP7rFpfcuI22on3tw97w4N
    jose-0.10.0.1-GrTWLmxH0e099v2AnsI6W3
    lens-5.3.5-4EpbRAR8ZTG3BQIWlRa9Ae
    lens-aeson-1.2.3-EnSlz3AQX1f2QiN2b6V7kf mtl-2.3.1
    network-3.1.4.0-2vzg6cg8x4bL2vbL886yck
    network-uri-2.6.4.2-Lsaf0h0B6LzHuoHWbm4G86
    optparse-applicative-0.18.1.0-3se4EOVlv606hLWBZRUZg0
    parsec-3.1.16.1 protolude-0.3.5-1vCZ8eDgQkP187cPakhCDA
    regex-tdfa-1.3.2.5-3SUtr6zl8m4ZpuEbYfBOR
    retry-0.9.3.1-5x2pf8gve50JyhcMKOM80u
    scientific-0.3.8.1-7wrrztUTJAME8Zylkxnjb5
    swagger2-2.9-4IqI0gaGMiB2FaPrY8wc3 text-2.0.2 time-1.12.2
    unix-2.8.4.0 unordered-containers-0.2.21-DZIhPqSL0N2YNV8fYQEJ8
    vault-0.3.1.6-HHJRKN48g6jKts9ed1QoiT
    vector-0.13.2.0-746bkLFippyHVcwUkeKsy
    wai-3.2.4-IKgxkjjKxwqDDCzhjgpXG
    wai-cors-0.2.7-EeQXvBZip94HnVFdVzE09F
    wai-extra-3.1.18-BMBf2TTXfgQGi8ie1exRyh
    wai-logger-2.5.0-CnYUsh7iODa4Z2YDlJFKif
    warp-3.4.0-KQM9zswsvKP93GmnVGdCr

haddock-interfaces:   /usr/share/doc/postgrest/html/postgrest.haddock
haddock-html:         /usr/share/doc/postgrest/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

